==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/MshUtils/ReadMsh/ReadMsh2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"ReadMsh.h"

void
ReadMshHead (FILE * msh)
{
  char string1[100], string2[100];

  /* Reading of the 2 first strings, which must be "$MeshFormat" and "2". */
  fscanf (msh, "%s", string1);
  fscanf (msh, "%s", string2);

  if (strcmp (string1, "$MeshFormat") != 0)
  {
    ut_print_message (2, "Input file is not a msh file!\n");
    ut_print_message (2, "(start word does not match.)\n");
    abort ();
  }

  if (strcmp (string2, "2") != 0)
  {
    ut_print_message (2, "Bad msh file format version detected!\n");
    abort ();
  }

  /* Then, the next 3 ones are trashed. */
  FTrash (3, msh);

  return;
}

void
ReadNodes (struct NODES *pNodes, FILE * msh)
{
  (*pNodes).NodeQty = ReadNodesHead (msh);

  ReadNodesProp (pNodes, msh);

  ReadNodesFoot (msh);

  return;
}

void
ReadElts (struct MESH *pMesh0D, struct MESH *pMesh1D,
	  struct MESH *pMesh2D, struct MESH *pMesh3D, FILE * msh)
{
  int remainingelts;
  int *Residual = oneDDoubleDAlloc_int (2);

  remainingelts = ReadEltsHead (msh);

  remainingelts -= ReadEltsOfDim (pMesh0D, 0, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh1D, 1, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh2D, 2, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh3D, 3, remainingelts, Residual, msh);

  if (remainingelts != 0)
  {
    ut_print_message (2, "Reading of mesh file failed!\n");
    ut_print_message (2, "(Element quantity does not match.)\n");
    abort ();
  }

  ReadEltsFoot (msh);
  oneDIntFree (Residual);

  return;
}

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/MshUtils/ReadMsh/ReadMsh2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"ReadMsh.h"

void
ReadMshHead (FILE * msh)
{
  char string1[100], string2[100];

  /* Reading of the 2 first strings, which must be "$MeshFormat" and "2". */
  fscanf (msh, "%s", string1);
  fscanf (msh, "%s", string2);

  if (strcmp (string1, "$MeshFormat") != 0)
  {
    ut_print_message (2, "Input file is not a msh file!\n");
    ut_print_message (2, "(start word does not match.)\n");
    abort ();
  }

  if (strcmp (string2, "2") != 0)
  {
    ut_print_message (2, "Bad msh file format version detected!\n");
    abort ();
  }

  /* Then, the next 3 ones are trashed. */
  FTrash (3, msh);

  return;
}

void
ReadNodes (struct NODES *pNodes, FILE * msh)
{
  (*pNodes).NodeQty = ReadNodesHead (msh);

  ReadNodesProp (pNodes, msh);

  ReadNodesFoot (msh);

  return;
}

void
ReadElts (struct MESH *pMesh0D, struct MESH *pMesh1D,
	  struct MESH *pMesh2D, struct MESH *pMesh3D, FILE * msh)
{
  int remainingelts;
  int *Residual = ut_alloc_1d_int (2);

  remainingelts = ReadEltsHead (msh);
  remainingelts -= ReadEltsOfDim (pMesh0D, 0, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh1D, 1, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh2D, 2, remainingelts, Residual, msh);
  remainingelts -= ReadEltsOfDim (pMesh3D, 3, remainingelts, Residual, msh);

  if (remainingelts != 0)
  {
    ut_print_message (2, "Reading of mesh file failed!\n");
    ut_print_message (2, "(Element quantity does not match.)\n");
    abort ();
  }

  ReadEltsFoot (msh);
  oneDIntFree (Residual);

  return;
}
